"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const data_packet_service_1 = require("./service/data-packet-service");
const minespider_service_1 = require("./service/minespider-service");
const ethereum_service_1 = require("./service/ethereum-service");
const file_store_service_1 = require("./service/file-store-service");
const backend_service_1 = require("./service/backend-service");
const config = {
    'minespider-contract-address': '0x5b3e89170a1ca835484df137727110e06cd55af2',
    'data-packets-storage-address': '0xea36f1ca854a5e323bbf01537d6e447174d17495',
    'silq-token-address': '0x48cd5c09c2e6595b52712d3174318a73a5bb75c8',
    'backend-host': 'https://backend.app.minespider.com',
};
var data_packet_service_2 = require("./service/data-packet-service");
exports.DataPacketEnvelope = data_packet_service_2.DataPacketEnvelope;
exports.KeyPacket = data_packet_service_2.KeyPacket;
var web3_adapter_1 = require("./adapter/web3-adapter");
exports.Web3Adapter = web3_adapter_1.Web3Adapter;
var provider_adapter_1 = require("./adapter/provider-adapter");
exports.EntityType = provider_adapter_1.EntityType;
var Material;
(function (Material) {
    Material[Material["Gold"] = 0] = "Gold";
    Material[Material["Silver"] = 1] = "Silver";
    Material[Material["Diamond"] = 2] = "Diamond";
    Material[Material["Silica"] = 3] = "Silica";
})(Material = exports.Material || (exports.Material = {}));
class SellDataPacketsCommand {
    constructor(packets, cmw, newOwnerAddress, newOwnerPublicKey, publicFiles, privateFiles) {
        this.packets = packets;
        this.cmw = cmw;
        this.newOwnerAddress = newOwnerAddress;
        this.newOwnerPublicKey = newOwnerPublicKey;
        this.publicFiles = publicFiles;
        this.privateFiles = privateFiles;
    }
}
exports.SellDataPacketsCommand = SellDataPacketsCommand;
class Minespider {
    constructor(providerAdapter) {
        if (!providerAdapter.wasInitiated()) {
            providerAdapter.init(config['minespider-contract-address'], config['data-packets-storage-address'], config['silq-token-address']);
        }
        this.ethereumService = new ethereum_service_1.EthereumService(providerAdapter);
        this.fileStoreService = new file_store_service_1.FileStoreService(config['backend-host']);
        this.backendService = new backend_service_1.BackendService(config['backend-host'], this.ethereumService);
        this.minespiderService = new minespider_service_1.MinespiderService(this.ethereumService, this.backendService);
        this.dataPacketService = new data_packet_service_1.DataPacketService(this.fileStoreService, this.ethereumService, this.backendService);
    }
    async registerEntity(entity) {
        return this.minespiderService.registerEntity(entity);
    }
    async certifyDataPacket(certifyDataPacketCommand, privateKeyHex) {
        return new Promise(async (resolve, reject) => {
            try {
                let trackingData = new data_packet_service_1.TrackingData(certifyDataPacketCommand.cmw, certifyDataPacketCommand.rawAmount, certifyDataPacketCommand.grade, certifyDataPacketCommand.geoLocation[0], certifyDataPacketCommand.geoLocation[1], Material[certifyDataPacketCommand.materialId]);
                let dataPacketEnvelopeAddress = await this.dataPacketService.certifyDataPacket(trackingData, certifyDataPacketCommand.publicFiles, certifyDataPacketCommand.privateFiles);
                await this.backendService.registerDataPacketEnvelopeAddress(await this.ethereumService.getCurrentAccountAddress(), dataPacketEnvelopeAddress, Buffer.from(privateKeyHex));
                resolve(dataPacketEnvelopeAddress);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async sellPacket(dataPacketEnvelope, cmw, newOwnerAddress, publicFiles, privateFiles, currentOwnerPrivateKey) {
        return this.dataPacketService.sellDataPacket(dataPacketEnvelope, cmw, newOwnerAddress, publicFiles, privateFiles, currentOwnerPrivateKey);
    }
    async getPacket(packetId) {
        return this.dataPacketService.getPacket(packetId);
    }
    async getMyDataPackets() {
        return this.dataPacketService.getMyDataPackets();
    }
    async downloadDataPacketEnvelope(address, privateKey) {
        return this.dataPacketService.downloadDataPacketEnvelope(address, privateKey);
    }
    async getDataPacketEnvelopes(owner, privateKey) {
        return new Promise(async (resolve, reject) => {
            try {
                let dataPacketEnvelopeAddresses = await this.backendService.getDataPacketEnvelopeAddresses(owner);
                let dataPacketEnvelopes = [];
                for (let address of dataPacketEnvelopeAddresses) {
                    dataPacketEnvelopes.push(await this.dataPacketService.downloadDataPacketEnvelope(address, privateKey));
                }
                resolve(dataPacketEnvelopes);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async downloadFile(key, address) {
        return this.dataPacketService.downloadFile(key, address);
    }
    async downloadFiles(keyPacket) {
        return this.dataPacketService.downloadFiles(keyPacket);
    }
    async downloadMetadataFiles(keyPacket) {
        return this.dataPacketService.downloadMetadataFiles(keyPacket);
    }
    async updateSilqTokenAddress(newAddress) {
        return this.minespiderService.updateSilqTokenAddress(newAddress);
    }
    async updateMinespiderAddress(newAddress) {
        return this.minespiderService.updateMinespiderAddress(newAddress);
    }
    async updateDataPacketStorageAddress(newAddress) {
        return this.minespiderService.updateDataPacketStorageAddress(newAddress);
    }
    async modifyMassBalanceCertification(producerId, materialId, cmw) {
        return this.minespiderService.modifyMassBalanceCertification(producerId, Material[materialId], cmw);
    }
    async getCurrentAccountAddress() {
        return this.ethereumService.getCurrentAccountAddress();
    }
    async getEntityDetails(entityId) {
        return this.backendService.getEntity(entityId);
    }
    async getEntities(type) {
        return this.backendService.getEntities(type);
    }
    async getSILQBalance() {
        let address = await this.getCurrentAccountAddress();
        return this.ethereumService.getSILQBalance(address);
    }
    async getProducerMBCertification(producerId, materialId) {
        return {
            used: await this.ethereumService.getProducedMassBalance(producerId, Material[materialId]),
            total: await this.ethereumService.getCertifiedMassBalance(producerId, Material[materialId])
        };
    }
}
exports.Minespider = Minespider;
//# sourceMappingURL=index.js.map