"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const forge = require("node-forge");
const web3 = require("web3");
const webcrypto = require("webcrypto");
const eccrypto = require("eccrypto");
exports.crypto = webcrypto;
class AESKey {
    constructor(key, iv) {
        this.key = key;
        this.iv = iv;
    }
}
exports.AESKey = AESKey;
class KeyPair {
    constructor(publicKey, privateKey) {
        this.publicKey = publicKey;
        this.privateKey = privateKey;
    }
}
exports.KeyPair = KeyPair;
class EncryptionService {
    static generateKeyPair() {
        let privateKey = exports.crypto.randomBytes(32);
        let publicKey = eccrypto.getPublic(privateKey);
        let encodedPrivateKey = Buffer.from(web3.utils.bytesToHex(privateKey));
        let encodedPublicKey = Buffer.from(web3.utils.bytesToHex(publicKey));
        console.log('public key length', publicKey.length);
        return new KeyPair(encodedPublicKey, encodedPrivateKey);
    }
    static generateAESKey() {
        return new AESKey(Buffer.from(web3.utils.randomHex(32).substr(2, 32)), Buffer.from(web3.utils.randomHex(32).substr(2, 12)));
    }
    static encrypt(payload, AESKey) {
        var cipher = forge.cipher.createCipher('AES-CBC', forge.util.createBuffer(AESKey.key.toString(), 'Utf8'));
        cipher.start({ iv: AESKey.iv.toString() });
        cipher.update(forge.util.createBuffer(payload.toString(), 'Utf8'));
        cipher.finish();
        return cipher.output.getBytes().toString();
    }
    static decrypt(payload, AESKey) {
        let decipher = forge.cipher.createDecipher('AES-CBC', forge.util.createBuffer(AESKey.key.toString(), 'Utf8'));
        decipher.start({ iv: AESKey.iv.toString() });
        decipher.update(forge.util.createBuffer(payload, 'Utf8'));
        let result = decipher.finish();
        if (result === false) {
            throw new Error('Something went wrong while decrypting the message');
        }
        return Buffer.from(decipher.output.data);
    }
    static async encryptWithPublicKey(payload, encodedPublicKey) {
        return new Promise(async (resolve, reject) => {
            try {
                let bytesAsString = web3.utils.hexToBytes(encodedPublicKey.toString());
                let bytesAsArray = bytesAsString.toString().split(',');
                let publicKey = Buffer.from(bytesAsArray);
                let encrypted = await eccrypto.encrypt(publicKey, payload);
                resolve(Buffer.from(JSON.stringify(encrypted)));
            }
            catch (error) {
                reject(error);
            }
        });
    }
    static async decryptWithPrivateKey(payload, encodedPrivateKey) {
        return new Promise(async (resolve, reject) => {
            try {
                let bytesAsString = web3.utils.hexToBytes(encodedPrivateKey.toString());
                let bytesAsArray = bytesAsString.toString().split(',');
                let privateKey = Buffer.from(bytesAsArray);
                let encrypted = JSON.parse(payload.toString());
                let decrypted = await eccrypto.decrypt(privateKey, {
                    iv: Buffer.from(encrypted.iv.data),
                    ephemPublicKey: Buffer.from(encrypted.ephemPublicKey.data),
                    ciphertext: Buffer.from(encrypted.ciphertext.data),
                    mac: Buffer.from(encrypted.mac.data)
                });
                resolve(decrypted);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    static async signWithPrivateKey(payload, encodedPrivateKey) {
        return new Promise(async (resolve, reject) => {
            try {
                let bytesAsString = web3.utils.hexToBytes(encodedPrivateKey.toString());
                let bytesAsArray = bytesAsString.toString().split(',');
                let privateKey = Buffer.from(bytesAsArray);
                let payloadHash = exports.crypto
                    .createHash('sha256')
                    .update(payload.toString())
                    .digest();
                let signature = JSON.stringify(await eccrypto.sign(privateKey, payloadHash));
                resolve(signature);
            }
            catch (error) {
                reject(error);
            }
        });
    }
}
exports.EncryptionService = EncryptionService;
//# sourceMappingURL=encryption-service.js.map