"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const Web3 = require("web3");
const encryption_service_1 = require("./encryption-service");
const shasum = (content) => {
    return crypto
        .createHash('sha1')
        .update(content.toString('utf8'))
        .digest('hex');
};
class EthereumService {
    constructor(provider) {
        this.provider = provider;
    }
    async registerEntity(entity) {
        return new Promise(async (resolve, reject) => {
            let keyPair = encryption_service_1.EncryptionService.generateKeyPair();
            try {
                await this.provider.registerEntity(entity);
                resolve(keyPair);
            }
            catch (error) {
                reject({
                    error: error,
                    keyPair: encryption_service_1.KeyPair
                });
            }
        });
    }
    async modifyMassBalanceCertification(producerId, materialId, cmw) {
        return new Promise(async (resolve, reject) => {
            try {
                let transactionHash = await this.provider.modifyMassBalanceCertification(producerId, materialId, cmw);
                resolve(transactionHash);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async certifyDataPacket(packetId, cmw, materialId, publicFilesAddresses, privateFilesAddresses) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.certifyDataPacket(packetId, cmw, materialId, publicFilesAddresses, privateFilesAddresses);
                resolve(packetId);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async getPacket(packetId) {
        return new Promise(async (resolve, reject) => {
            try {
                resolve(this.provider.getPacket(packetId));
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async sellPacket(packetId, newPacketId, newOwnerAddress, cmw, publicFilesAddresses, privateFilesAddresses) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.sellPacket(packetId, newPacketId, newOwnerAddress, cmw, publicFilesAddresses, privateFilesAddresses);
                resolve(newPacketId);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async splitAndSellPacket(packetId, newOwnerAddress, part1Id, part2Id, amountToSell, publicFilesAddresses, privateFilesAddresses) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.splitAndSellPacket(packetId, newOwnerAddress, part1Id, part2Id, amountToSell, publicFilesAddresses, privateFilesAddresses);
                resolve(part1Id);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async updateSilqTokenAddress(newAddress) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.updateSilqTokenAddress(newAddress);
                resolve(newAddress);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async updateMinespiderAddress(newAddress) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.updateMinespiderAddress(newAddress);
                resolve(newAddress);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async updateDataPacketStorageAddress(newAddress) {
        return new Promise(async (resolve, reject) => {
            try {
                await this.provider.updateDataPacketStorageAddress(newAddress);
                resolve(newAddress);
            }
            catch (error) {
                reject(error);
            }
        });
    }
    async getSILQBalance(address) {
        return this.provider.getSILQBalance(address);
    }
    async getProducedMassBalance(producerId, materialId) {
        return this.provider.getProducedMassBalance(producerId, materialId);
    }
    async getCertifiedMassBalance(producerId, materialId) {
        return this.provider.getCertifiedMassBalance(producerId, materialId);
    }
    async getOwnedMassBalance(producerId, materialId) {
        return this.provider.getOwnedMassBalance(producerId, materialId);
    }
    async getCurrentAccountAddress() {
        return this.provider.getCurrentAccountAddress();
    }
    static isAddress(address) {
        return Web3.utils.isAddress(address);
    }
    static bytesToHex(content) {
        return Buffer.from(Web3.utils.bytesToHex(content));
    }
    static stringToHex(content) {
        return Buffer.from(Web3.utils.stringToHex(content.toString()));
    }
    static hexToString(content) {
        return Buffer.from(Web3.utils.hexToString(content.toString()));
    }
    static hexToBytes(content) {
        return Buffer.from(Web3.utils.hexToBytes(content.toString()));
    }
    static shasum(content) {
        return shasum(content);
    }
    static generateRandomHex(bytes) {
        var address = Web3.utils.randomHex(bytes);
        while (!Web3.utils.isAddress(address)) {
            address = Web3.utils.randomHex(bytes);
        }
        return address;
    }
}
exports.EthereumService = EthereumService;
//# sourceMappingURL=ethereum-service.js.map