import { Packet } from "../service/data-packet-service";
export declare enum EntityType {
    Certifier = 0,
    Producer = 1,
    Smelter = 2,
    Transporter = 3,
    StakeHolder = 4
}
export interface Entity {
    id: string;
    entityType: EntityType;
    name: string;
    latitude: string;
    longitude: string;
    location: string;
}
export interface ProviderAdapterInterface {
    wasInitiated(): boolean;
    init(minespiderContractAddress: string, dataPacketStorageAddress: string, silqTokenAddress: string): any;
    getCurrentAccountAddress(): Promise<string>;
    getSILQBalance(address: string): Promise<number>;
    getProducedMassBalance(producerId: string, materialId: string): Promise<number>;
    getCertifiedMassBalance(producerId: string, materialId: string): Promise<number>;
    getOwnedMassBalance(producerId: string, materialId: string): Promise<number>;
    registerEntity(entity: Entity): Promise<string>;
    modifyMassBalanceCertification(producerId: string, materialId: string, cmw: number): Promise<string>;
    certifyDataPacket(packetId: string, cmw: number, materialId: string, publicFilesAddresses: string[], privateFilesAddresses: string[]): Promise<string>;
    getPacket(packetId: string): Promise<Packet>;
    sellPacket(packetId: string, newPacketId: string, newOwnerAddress: string, cmw: number, publicFilesAddresses: any, privateFilesAddresses: any): Promise<string>;
    splitAndSellPacket(packetId: string, newOwnerAddress: string, part1Id: string, part2Id: string, amountToSell: number, publicFilesAddresses: any, privateFilesAddresses: any): any;
    updateSilqTokenAddress(newAddress: string): Promise<string>;
    updateMinespiderAddress(newAddress: string): Promise<string>;
    updateDataPacketStorageAddress(newAddress: string): Promise<string>;
}
